@@ -69,26 +69,13 @@
 /* #undef VTK_USE_WIN32_THREADS */
 # define VTK_MAX_THREADS 64
 
-/* Atomic operations */
-#define VTK_HAVE_SYNC_BUILTINS
-#if defined(_WIN32)
-/* #undef VTK_HAS_INTERLOCKEDADD */
-#endif
-
 /* vtkSMPTools back-end */
 #define VTK_SMP_Sequential
 #define VTK_SMP_BACKEND "Sequential"
 
-/* Compiler features.  */
-#define VTK_HAVE_GETSOCKNAME_WITH_SOCKLEN_T
-#define VTK_HAVE_SO_REUSEADDR
-
 /* Whether we require large files support.  */
 #define VTK_REQUIRE_LARGE_FILE_SUPPORT
 
-/* Whether reverse const iterator's have comparison operators. */
-#define VTK_CONST_REVERSE_ITERATOR_COMPARISON
-
 /*--------------------------------------------------------------------------*/
 /* VTK Platform Configuration                                               */
 
@@ -151,18 +138,11 @@
 # define VTK_MAXPATH 32767 // Possible with Windows "extended paths"
 #endif
 
-#if (__cplusplus >= 201103L) || ( defined(_MSC_VER) && _MSC_VER >= 1700 )
+/* TODO: wrap in #ifndef VTK_LEGACY_REMOVE */
+#if 1
 # define VTK_OVERRIDE override
 # define VTK_FINAL final
-#else
-# define VTK_OVERRIDE
-# define VTK_FINAL
-#endif
-
-#if (__cplusplus >= 201103L) || ( defined(_MSC_VER) && _MSC_VER >= 1800 )
 # define VTK_DELETE_FUNCTION =delete
-#else
-# define VTK_DELETE_FUNCTION
 #endif
 
 /** extern template declarations for C++11
