@@ -13,8 +13,8 @@
 
 =========================================================================*/
 
-#ifndef __vtkIOMPIParallelObjectFactory_h
-#define __vtkIOMPIParallelObjectFactory_h
+#ifndef vtkIOMPIParallelObjectFactory_h
+#define vtkIOMPIParallelObjectFactory_h
 
 #include "vtkIOMPIParallelModule.h" // For export macro
 #include "vtkObjectFactory.h"
@@ -25,18 +25,18 @@ public:
   static vtkIOMPIParallelObjectFactory * New();
   vtkTypeMacro(vtkIOMPIParallelObjectFactory, vtkObjectFactory)
 
-  const char * GetDescription() { return "vtkIOMPIParallel factory overrides."; }
+  const char * GetDescription() override { return "vtkIOMPIParallel factory overrides."; }
 
-  const char * GetVTKSourceVersion();
+  const char * GetVTKSourceVersion() override;
 
-  void PrintSelf(ostream &os, vtkIndent indent);
+  void PrintSelf(ostream &os, vtkIndent indent) override;
 
 protected:
   vtkIOMPIParallelObjectFactory();
 
 private:
-  vtkIOMPIParallelObjectFactory(const vtkIOMPIParallelObjectFactory&); // Not implemented
-  void operator=(const vtkIOMPIParallelObjectFactory&);      // Not implemented
+  vtkIOMPIParallelObjectFactory(const vtkIOMPIParallelObjectFactory&) = delete;
+  void operator=(const vtkIOMPIParallelObjectFactory&) = delete;
 };
 
-#endif // __vtkIOMPIParallelObjectFactory_h
+#endif // vtkIOMPIParallelObjectFactory_h
